@@ -15,7 +15,6 @@ import sys
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_comprehendmedical.type_defs import (
     ComprehendMedicalAsyncJobFilterTypeDef,
@@ -53,21 +52,29 @@ else:
 __all__ = ("ComprehendMedicalClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    InvalidEncodingException: Type[Boto3ClientError]
-    InvalidRequestException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ServiceUnavailableException: Type[Boto3ClientError]
-    TextSizeLimitExceededException: Type[Boto3ClientError]
-    TooManyRequestsException: Type[Boto3ClientError]
-    ValidationException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    InvalidEncodingException: Type[BotocoreClientError]
+    InvalidRequestException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceUnavailableException: Type[BotocoreClientError]
+    TextSizeLimitExceededException: Type[BotocoreClientError]
+    TooManyRequestsException: Type[BotocoreClientError]
+    ValidationException: Type[BotocoreClientError]
 
 
 class ComprehendMedicalClient:
     """
-    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     """
 
     meta: ClientMeta
@@ -75,48 +82,48 @@ class ComprehendMedicalClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         """
 
     def describe_entities_detection_v2_job(
         self, JobId: str
     ) -> DescribeEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         """
 
     def describe_icd10_cm_inference_job(
         self, JobId: str
     ) -> DescribeICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.describe_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
+        [Client.describe_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
         """
 
     def describe_phi_detection_job(self, JobId: str) -> DescribePHIDetectionJobResponseTypeDef:
         """
-        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         """
 
     def describe_rx_norm_inference_job(
         self, JobId: str
     ) -> DescribeRxNormInferenceJobResponseTypeDef:
         """
-        [Client.describe_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
+        [Client.describe_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
         """
 
     def detect_entities(self, Text: str) -> DetectEntitiesResponseTypeDef:
         """
-        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         """
 
     def detect_entities_v2(self, Text: str) -> DetectEntitiesV2ResponseTypeDef:
         """
-        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         """
 
     def detect_phi(self, Text: str) -> DetectPHIResponseTypeDef:
         """
-        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         """
 
     def generate_presigned_url(
@@ -127,17 +134,17 @@ class ComprehendMedicalClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         """
 
     def infer_icd10_cm(self, Text: str) -> InferICD10CMResponseTypeDef:
         """
-        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         """
 
     def infer_rx_norm(self, Text: str) -> InferRxNormResponseTypeDef:
         """
-        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         """
 
     def list_entities_detection_v2_jobs(
@@ -147,7 +154,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListEntitiesDetectionV2JobsResponseTypeDef:
         """
-        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         """
 
     def list_icd10_cm_inference_jobs(
@@ -157,7 +164,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListICD10CMInferenceJobsResponseTypeDef:
         """
-        [Client.list_icd10_cm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
+        [Client.list_icd10_cm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
         """
 
     def list_phi_detection_jobs(
@@ -167,7 +174,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListPHIDetectionJobsResponseTypeDef:
         """
-        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         """
 
     def list_rx_norm_inference_jobs(
@@ -177,7 +184,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListRxNormInferenceJobsResponseTypeDef:
         """
-        [Client.list_rx_norm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
+        [Client.list_rx_norm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
         """
 
     def start_entities_detection_v2_job(
@@ -191,7 +198,7 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> StartEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         """
 
     def start_icd10_cm_inference_job(
@@ -205,7 +212,7 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> StartICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.start_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
+        [Client.start_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
         """
 
     def start_phi_detection_job(
@@ -219,7 +226,7 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> StartPHIDetectionJobResponseTypeDef:
         """
-        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         """
 
     def start_rx_norm_inference_job(
@@ -233,27 +240,27 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> StartRxNormInferenceJobResponseTypeDef:
         """
-        [Client.start_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
+        [Client.start_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
         """
 
     def stop_entities_detection_v2_job(
         self, JobId: str
     ) -> StopEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         """
 
     def stop_icd10_cm_inference_job(self, JobId: str) -> StopICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.stop_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
+        [Client.stop_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
         """
 
     def stop_phi_detection_job(self, JobId: str) -> StopPHIDetectionJobResponseTypeDef:
         """
-        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         """
 
     def stop_rx_norm_inference_job(self, JobId: str) -> StopRxNormInferenceJobResponseTypeDef:
         """
-        [Client.stop_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
+        [Client.stop_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
         """
